@@ -22,8 +22,8 @@ func TestDocChapter(t *testing.T) {
 		wantInDoc string
 		wantErr   bool
 	}{
-		"Get documentation chapter":                     {chapter: "how-to-guides/set-up-ad", wantInDoc: "# How to set up the Active Directory Server"},
-		"Get documentation chapter with incorrect case": {chapter: "HoW-to-guIdes/set-Up-AD", wantInDoc: "# How to set up the Active Directory Server"},
+		"Get documentation chapter":                     {chapter: "how-to-guides/setting-up-active-directory", wantInDoc: "# How to set up the Active Directory server for Ubuntu clients"},
+		"Get documentation chapter with incorrect case": {chapter: "HoW-to-guIdes/setting-Up-Active-directory", wantInDoc: "# How to set up the Active Directory server for Ubuntu clients"},
 
 		// Section cases
 		"Section using alias":                  {chapter: "how-to-guides", wantInDoc: "# How-to guides"},
@@ -34,14 +34,13 @@ func TestDocChapter(t *testing.T) {
 		"Get main index with no parameter":         {wantInDoc: "# ADSys Documentation"},
 		"Get main index with index title doc name": {chapter: "adsys-documentation", wantInDoc: "# ADSys Documentation"},
 
-		"Get documentation is always authorized": {systemAnswer: "polkit_no", chapter: "how-to-guides/set-up-ad", wantInDoc: "# How to set up the Active Directory Server"},
+		"Get documentation is always authorized": {systemAnswer: "polkit_no", chapter: "how-to-guides/setting-up-active-directory", wantInDoc: "# How to set up the Active Directory server for Ubuntu clients"},
 
 		// Error cases
 		"Error on daemon not responding": {daemonNotStarted: true, wantErr: true},
 		"Error on nonexistent chapter":   {chapter: "nonexistent-chapter", wantErr: true},
 	}
 	for name, tc := range tests {
-		tc := tc
 		t.Run(name, func(t *testing.T) {
 			if tc.systemAnswer == "" {
 				tc.systemAnswer = "polkit_yes"
@@ -91,7 +90,6 @@ func TestDocCompletion(t *testing.T) {
 		"Empty completion content on daemon not responding": {daemonNotStarted: true, wantCompletionEmpty: true},
 	}
 	for name, tc := range tests {
-		tc := tc
 		t.Run(name, func(t *testing.T) {
 			if tc.systemAnswer == "" {
 				tc.systemAnswer = "polkit_yes"
@@ -117,12 +115,13 @@ func TestDocCompletion(t *testing.T) {
 			// Ensure that all interesting docs are listed here (and so. linked to their TOC)
 			var wantNumDocs int
 			docsDir := filepath.Join(rootProjectDir, "docs")
-			err = filepath.WalkDir(docsDir, func(path string, d fs.DirEntry, err error) error {
+			err = filepath.WalkDir(docsDir, func(path string, d fs.DirEntry, _ error) error {
 				// Ignore directories, every reference doc under reuse, compiled content and any autogenerated policy documentation.
 				if d.IsDir() ||
 					strings.HasPrefix(path, filepath.Join(docsDir, "reuse")) ||
 					strings.HasPrefix(path, docsDir+"/.") ||
-					strings.HasPrefix(path, filepath.Join(docsDir, "reference", "policies")) {
+					strings.HasPrefix(path, filepath.Join(docsDir, "reference", "policies")) ||
+					strings.HasPrefix(path, filepath.Join(docsDir, "diagrams")) {
 					return nil
 				}
 				if !strings.HasSuffix(d.Name(), ".md") {
@@ -138,7 +137,7 @@ func TestDocCompletion(t *testing.T) {
 			assert.Len(t, completions, wantNumDocs+2, "Should list all available documentation md files from docs/")
 
 			assert.Contains(t, completions, "how-to-guides", "contain a section index")
-			assert.Contains(t, completions, "how-to-guides/set-up-ad", "contain a section sub chapter with alias")
+			assert.Contains(t, completions, "how-to-guides/setting-up-active-directory", "contain a section sub chapter with alias")
 		})
 	}
 }
