@@ -24,7 +24,7 @@ The program will monitor the configured directories for changes and bump the app
 If a GPT.ini file does not exist for a directory, a warning will be issued and the file will be created. If the GPT.ini file is incompatible or malformed, the program will report an error.
 `),
 		Args: cobra.NoArgs,
-		RunE: func(cmd *cobra.Command, args []string) error {
+		RunE: func(_ *cobra.Command, _ []string) error {
 			if len(a.config.Dirs) < 1 {
 				return errors.New(gotext.Get("run command needs at least one directory to watch either with --dirs or via the configuration file"))
 			}
@@ -33,11 +33,10 @@ If a GPT.ini file does not exist for a directory, a warning will be issued and t
 			if service.Interactive() {
 				if status, _ := a.service.Status(context.Background()); strings.Contains(status, "running") {
 					msg := gotext.Get("another instance of the %s service is already running", watchdconfig.CmdName)
-
 					if !a.config.Force {
 						return errors.New(gotext.Get("%s, use --force to override", msg))
 					}
-					log.Warningf(context.Background(), gotext.Get(msg))
+					log.Warning(context.Background(), msg)
 				}
 			}
 
@@ -53,7 +52,8 @@ If a GPT.ini file does not exist for a directory, a warning will be issued and t
 		[]string{},
 		gotext.Get("a `directory` to check for changes (can be specified multiple times)"),
 	)
-	decorate.LogOnError(a.viper.BindPFlag("dirs", cmd.Flags().Lookup("dirs")))
+	err := a.viper.BindPFlag("dirs", cmd.Flags().Lookup("dirs"))
+	decorate.LogOnError(&err)
 
 	cmd.Flags().BoolP(
 		"force",
@@ -61,7 +61,8 @@ If a GPT.ini file does not exist for a directory, a warning will be issued and t
 		false,
 		gotext.Get("force the program to run even if another instance is already running"),
 	)
-	decorate.LogOnError(a.viper.BindPFlag("force", cmd.Flags().Lookup("force")))
+	err = a.viper.BindPFlag("force", cmd.Flags().Lookup("force"))
+	decorate.LogOnError(&err)
 	cmdhandler.InstallConfigFlag(cmd, false)
 
 	a.rootCmd.AddCommand(cmd)
