@@ -20,12 +20,12 @@ import (
 	"sync"
 	"time"
 
+	"github.com/leonelquinteros/gotext"
 	"github.com/ubuntu/adsys/internal/ad/backends"
 	adcommon "github.com/ubuntu/adsys/internal/ad/common"
 	"github.com/ubuntu/adsys/internal/ad/registry"
 	"github.com/ubuntu/adsys/internal/consts"
 	log "github.com/ubuntu/adsys/internal/grpc/logstreamer"
-	"github.com/ubuntu/adsys/internal/i18n"
 	"github.com/ubuntu/adsys/internal/policies"
 	"github.com/ubuntu/adsys/internal/policies/entry"
 	"github.com/ubuntu/adsys/internal/smbsafe"
@@ -79,6 +79,7 @@ type AD struct {
 
 	withoutKerberos bool
 	gpoListCmd      []string
+	gpoListTimeout  time.Duration
 }
 
 type options struct {
@@ -88,6 +89,7 @@ type options struct {
 
 	withoutKerberos bool
 	gpoListCmd      []string
+	gpoListTimeout  time.Duration
 }
 
 // Option reprents an optional function to change AD behavior.
@@ -109,6 +111,14 @@ func WithRunDir(runDir string) Option {
 	}
 }
 
+// WithGpoListTimeout specifies a custom timeout for the adsys-gpolist command.
+func WithGpoListTimeout(timeout time.Duration) Option {
+	return func(o *options) error {
+		o.gpoListTimeout = timeout
+		return nil
+	}
+}
+
 // AdsysGpoListCode is the embedded script which request
 // Samba to get our GPO list for the given object.
 //
@@ -117,7 +127,7 @@ var AdsysGpoListCode string
 
 // New returns an AD object to manage concurrency, with a local kr5 ticket from machine keytab.
 func New(ctx context.Context, configBackend backends.Backend, hostname string, opts ...Option) (ad *AD, err error) {
-	defer decorate.OnError(&err, i18n.G("can't create Active Directory object"))
+	defer decorate.OnError(&err, gotext.Get("can't create Active Directory object"))
 
 	versionID, err := adcommon.GetVersionID("/")
 	if err != nil {
@@ -126,10 +136,11 @@ func New(ctx context.Context, configBackend backends.Backend, hostname string, o
 
 	// defaults
 	args := options{
-		runDir:     consts.DefaultRunDir,
-		cacheDir:   consts.DefaultCacheDir,
-		gpoListCmd: []string{"python3", "-c", AdsysGpoListCode},
-		versionID:  versionID,
+		runDir:         consts.DefaultRunDir,
+		cacheDir:       consts.DefaultCacheDir,
+		gpoListCmd:     []string{"python3", "-c", AdsysGpoListCode},
+		versionID:      versionID,
+		gpoListTimeout: 30 * time.Second, // this is used in tests and set to consts.DefaultGpoListTimeout in production
 	}
 	// applied options
 	for _, o := range opts {
@@ -155,7 +166,7 @@ func New(ctx context.Context, configBackend backends.Backend, hostname string, o
 	domain := configBackend.Domain()
 	serverFQDN, err := configBackend.ServerFQDN(ctx)
 	if err != nil && !errors.Is(err, backends.ErrNoActiveServer) {
-		return nil, fmt.Errorf(i18n.G("can't get current Server FQDN: %w"), err)
+		return nil, errors.New(gotext.Get("can't get current Server FQDN: %v", err))
 	}
 	log.Debugf(ctx, "Backend is SSSD. AD domain: %q, server from configuration: %q", domain, serverFQDN)
 
@@ -167,8 +178,9 @@ func New(ctx context.Context, configBackend backends.Backend, hostname string, o
 		policiesCacheDir: policiesCacheDir,
 		krb5CacheDir:     krb5CacheDir,
 
-		downloadables: make(map[string]*downloadable),
-		gpoListCmd:    args.gpoListCmd,
+		downloadables:  make(map[string]*downloadable),
+		gpoListCmd:     args.gpoListCmd,
+		gpoListTimeout: args.gpoListTimeout,
 	}, nil
 }
 
@@ -180,16 +192,16 @@ func New(ctx context.Context, configBackend backends.Backend, hostname string, o
 // The GPOs are returned from the highest priority in the hierarchy, with enforcement in reverse order
 // to the lowest priority.
 func (ad *AD) GetPolicies(ctx context.Context, objectName string, objectClass ObjectClass, userKrb5CCName string) (pols policies.Policies, err error) {
-	defer decorate.OnError(&err, i18n.G("can't get policies for %q"), objectName)
+	defer decorate.OnError(&err, gotext.Get("can't get policies for %q", objectName))
 
 	log.Debugf(ctx, "GetPolicies for %q, type %q", objectName, objectClass)
 
 	if objectClass == UserObject && !strings.Contains(objectName, "@") {
-		return pols, fmt.Errorf(i18n.G("user name %q should be of the form %s@DOMAIN"), objectName, objectName)
+		return pols, errors.New(gotext.Get("user name %q should be of the form %s@DOMAIN", objectName, objectName))
 	}
 
 	if objectClass == ComputerObject && objectName != ad.hostname {
-		return pols, fmt.Errorf(i18n.G("requested a type computer of %q which isn't current host %q"), objectName, ad.hostname)
+		return pols, errors.New(gotext.Get("requested a type computer of %q which isn't current host %q", objectName, ad.hostname))
 	}
 
 	krb5CCPath := filepath.Join(ad.krb5CacheDir, objectName)
@@ -225,7 +237,7 @@ func (ad *AD) GetPolicies(ctx context.Context, objectName string, objectClass Ob
 	if !online {
 		var cachedPolicies policies.Policies
 		if cachedPolicies, err = policies.NewFromCache(ctx, filepath.Join(ad.policiesCacheDir, objectName)); err != nil {
-			return cachedPolicies, fmt.Errorf(i18n.G("machine is offline and policies cache is unavailable: %v"), err)
+			return cachedPolicies, errors.New(gotext.Get("machine is offline and policies cache is unavailable: %v", err))
 		}
 
 		log.Infof(ctx, "Can't reach AD: machine is offline and %q policies are applied using previous online update", objectName)
@@ -235,14 +247,14 @@ func (ad *AD) GetPolicies(ctx context.Context, objectName string, objectClass Ob
 	// We need an AD DC to connect to
 	adServerFQDN, err := ad.configBackend.ServerFQDN(ctx)
 	if err != nil {
-		return policies.Policies{}, fmt.Errorf(i18n.G("can't get current Server FQDN: %w"), err)
+		return policies.Policies{}, errors.New(gotext.Get("can't get current Server FQDN: %v", err))
 	}
 
 	// Otherwise, try fetching the GPO list from LDAP
 	args := append([]string{}, ad.gpoListCmd...) // Copy gpoListCmd to prevent data race
 	scriptArgs := []string{"--objectclass", string(objectClass), adServerFQDN, objectName}
 	cmdArgs := append(args, scriptArgs...)
-	cmdCtx, cancel := context.WithTimeout(ctx, time.Second*10)
+	cmdCtx, cancel := context.WithTimeout(ctx, ad.gpoListTimeout)
 	defer cancel()
 	log.Debugf(ctx, "Getting gpo list with arguments: %q", strings.Join(scriptArgs, " "))
 	// #nosec G204 - cmdArgs is under our control (python embedded script or mock for tests)
@@ -256,7 +268,7 @@ func (ad *AD) GetPolicies(ctx context.Context, objectName string, objectClass Ob
 	err = cmd.Run()
 	smbsafe.DoneExec()
 	if err != nil {
-		return pols, fmt.Errorf(i18n.G("failed to retrieve the list of GPO (exited with %d): %v\n%s"), cmd.ProcessState.ExitCode(), err, stderr.String())
+		return pols, errors.New(gotext.Get("failed to retrieve the list of GPO (exited with %d): %v\n%s", cmd.ProcessState.ExitCode(), err, stderr.String()))
 	}
 
 	downloadables := make(map[string]string)
@@ -347,7 +359,7 @@ func (ad *AD) GetPolicies(ctx context.Context, objectName string, objectClass Ob
 // ListUsers returns the list of users on the system based on their cached policy information.
 // If active is true, the list of users is retrieved from the cached Kerberos ticket information.
 func (ad *AD) ListUsers(ctx context.Context, active bool) (users []string, err error) {
-	defer decorate.OnError(&err, i18n.G("can't list users from cache"))
+	defer decorate.OnError(&err, gotext.Get("can't list users from cache"))
 
 	log.Debug(ctx, "ListUsers")
 
@@ -361,7 +373,7 @@ func (ad *AD) ListUsers(ctx context.Context, active bool) (users []string, err e
 
 	entries, err := os.ReadDir(cacheDir)
 	if err != nil {
-		return users, fmt.Errorf(i18n.G("failed to read cache directory: %v"), err)
+		return users, errors.New(gotext.Get("failed to read cache directory: %v", err))
 	}
 
 	for _, entry := range entries {
@@ -390,7 +402,7 @@ func (ad *AD) ensureKrb5CCSymlink(srcKrb5CCName, dstKrb5CCName string) error {
 
 	srcKrb5CCName, err := filepath.Abs(srcKrb5CCName)
 	if err != nil {
-		return fmt.Errorf(i18n.G("can't get absolute path of ccname to symlink to: %v"), err)
+		return errors.New(gotext.Get("can't get absolute path of ccname to symlink to: %v", err))
 	}
 
 	src, err := os.Readlink(dstKrb5CCName)
@@ -401,12 +413,12 @@ func (ad *AD) ensureKrb5CCSymlink(srcKrb5CCName, dstKrb5CCName string) error {
 		}
 		// Delete the symlink to create a new one.
 		if err := os.Remove(dstKrb5CCName); err != nil {
-			return fmt.Errorf(i18n.G("failed to remove existing symlink: %v"), err)
+			return errors.New(gotext.Get("failed to remove existing symlink: %v", err))
 		}
 	}
 
 	if err := os.MkdirAll(filepath.Dir(dstKrb5CCName), 0700); err != nil {
-		return fmt.Errorf(i18n.G("failed to create parent directory for symlink: %w"), err)
+		return errors.New(gotext.Get("failed to create parent directory for symlink: %v", err))
 	}
 
 	if err := os.Symlink(srcKrb5CCName, dstKrb5CCName); err != nil {
@@ -428,14 +440,14 @@ func (ad *AD) ensureKrb5CCCopy(krb5CCSymlink, krb5CCCopyName string) error {
 
 	krb5CCSrc, err := os.Readlink(krb5CCSymlink)
 	if err != nil {
-		return fmt.Errorf(i18n.G("failed to read krb5cc symlink: %w"), err)
+		return errors.New(gotext.Get("failed to read krb5cc symlink: %v", err))
 	}
 
 	if copyStat, err := os.Lstat(krb5CCCopyName); err == nil && copyStat.Mode()&os.ModeSymlink == 0 {
 		// We already have a copy of the ticket, let's check if we need to update it
 		srcStat, err := os.Stat(krb5CCSrc)
 		if err != nil {
-			return fmt.Errorf(i18n.G("failed to stat source ticket: %w"), err)
+			return errors.New(gotext.Get("failed to stat source ticket: %v", err))
 		}
 
 		// The source ticket is not newer than the destination one, no need to update
@@ -459,7 +471,7 @@ func (ad *AD) ensureKrb5CCCopy(krb5CCSymlink, krb5CCCopyName string) error {
 func safeCopyFile(src, dst string, mode os.FileMode) error {
 	content, err := os.ReadFile(src)
 	if err != nil {
-		return fmt.Errorf(i18n.G("failed to read source file: %w"), err)
+		return errors.New(gotext.Get("failed to read source file: %v", err))
 	}
 	if err := os.WriteFile(dst+".new", content, mode); err != nil {
 		return err
@@ -479,111 +491,7 @@ func (ad *AD) parseGPOs(ctx context.Context, gpos []gpo, objectClass ObjectClass
 			Rules: make(map[string][]entry.Entry),
 		}
 		r = append(r, gpoWithRules)
-		if err := func() error {
-			ad.downloadables[name].mu.RLock()
-			defer ad.downloadables[name].mu.RUnlock()
-			_ = ad.downloadables[name].testConcurrent
-
-			log.Debugf(ctx, "Parsing GPO %q", name)
-
-			// We need to consider the uppercase version of the name as well,
-			// which could occur in some of the default GPOs such as Default
-			// Domain Policy.
-			classes := []string{"User", "USER"}
-			if objectClass == ComputerObject {
-				classes = []string{"Machine", "MACHINE"}
-			}
-
-			var err error
-			var f *os.File
-			for _, class := range classes {
-				var e error
-				f, e = os.Open(filepath.Join(ad.sysvolCacheDir, "Policies", filepath.Base(url), class, "Registry.pol"))
-
-				// We only care about the first error which is caused by opening
-				// the capitalized version of the class, instead of the
-				// uppercase version which is less common and more of an edge case.
-				if e != nil && err == nil {
-					err = e
-				} else if e == nil {
-					err = nil
-					break
-				}
-			}
-
-			if errors.Is(err, fs.ErrNotExist) {
-				log.Debugf(ctx, "Policy %q doesn't have any policy for class %q %s", name, objectClass, err)
-				return nil
-			} else if err != nil {
-				return err
-			}
-			defer decorate.LogFuncOnErrorContext(ctx, f.Close)
-
-			// Decode and apply policies in gpo order. First win
-			pols, err := registry.DecodePolicy(f)
-			if err != nil {
-				return fmt.Errorf(i18n.G("%s: %v"), f.Name(), err)
-			}
-
-			// filter keys to be overridden
-			var currentKey string
-			var overrideEnabled bool
-			for _, pol := range pols {
-				// Rewrite the certificate autoenrollment key so we can easily
-				// use it in the policy manager
-				if pol.Key == certAutoEnrollKey {
-					pol.Key = fmt.Sprintf("%scertificate/autoenroll/all", keyFilterPrefix)
-				}
-
-				if strings.HasPrefix(pol.Key, policyServersPrefix) {
-					pol.Key = fmt.Sprintf("%scertificate/%s/all", keyFilterPrefix, pol.Key)
-				}
-
-				// Only consider supported policies for this distro
-				if !strings.HasPrefix(pol.Key, keyFilterPrefix) {
-					continue
-				}
-				if pol.Err != nil {
-					return fmt.Errorf(i18n.G("%s: %v"), f.Name(), pol.Err)
-				}
-				pol.Key = strings.TrimPrefix(pol.Key, keyFilterPrefix)
-
-				// Some keys can be overridden
-				releaseID := filepath.Base(pol.Key)
-				keyType := strings.Split(pol.Key, "/")[0]
-				pol.Key = filepath.Dir(strings.TrimPrefix(pol.Key, keyType+"/"))
-
-				if releaseID == "all" {
-					currentKey = pol.Key
-					overrideEnabled = false
-					gpoWithRules.Rules[keyType] = append(gpoWithRules.Rules[keyType], pol)
-					continue
-				}
-
-				// This is not an "all" key and the key name don’t match
-				// This shouldn’t happen with our admx, but just to stay safe…
-				if currentKey != pol.Key {
-					continue
-				}
-
-				if strings.HasPrefix(releaseID, "Override"+ad.versionID) && pol.Value == "true" {
-					overrideEnabled = true
-					continue
-				}
-				// Check we have a matching override
-				if !overrideEnabled || releaseID != ad.versionID {
-					continue
-				}
-
-				// Matching enabled override
-				// Replace value with the override content
-				iLast := len(gpoWithRules.Rules[keyType]) - 1
-				p := gpoWithRules.Rules[keyType][iLast]
-				p.Value = pol.Value
-				gpoWithRules.Rules[keyType][iLast] = p
-			}
-			return nil
-		}(); err != nil {
+		if err = ad.parseGPO(ctx, name, url, keyFilterPrefix, objectClass, gpoWithRules); err != nil {
 			return r, err
 		}
 	}
@@ -591,6 +499,128 @@ func (ad *AD) parseGPOs(ctx context.Context, gpos []gpo, objectClass ObjectClass
 	return r, nil
 }
 
+func (ad *AD) parseGPO(ctx context.Context, name, url, keyFilterPrefix string, objectClass ObjectClass, gpoWithRules policies.GPO) error {
+	ad.downloadables[name].mu.RLock()
+	defer ad.downloadables[name].mu.RUnlock()
+	_ = ad.downloadables[name].testConcurrent
+
+	log.Debugf(ctx, "Parsing GPO %q of class %q", name, objectClass)
+
+	// We need to consider the uppercase version of the name as well,
+	// which could occur in some of the default GPOs such as Default
+	// Domain Policy.
+	classes := []string{"User", "USER"}
+	if objectClass == ComputerObject {
+		classes = []string{"Machine", "MACHINE"}
+	}
+
+	var f *os.File
+classLoop:
+	for _, class := range classes {
+		var err error
+		var files []os.DirEntry
+
+		policyDir := filepath.Join(ad.sysvolCacheDir, "Policies", filepath.Base(url), class)
+		files, err = os.ReadDir(policyDir)
+		if errors.Is(err, fs.ErrNotExist) {
+			log.Debugf(ctx, "Policy directory %q not found", policyDir)
+			continue
+		} else if err != nil {
+			return err
+		}
+
+		// Registry.pol can have different cases, ensure we can find it whatever its case is
+		for _, file := range files {
+			if !strings.EqualFold(file.Name(), "Registry.pol") {
+				continue
+			}
+
+			policyPath := filepath.Join(policyDir, file.Name())
+			log.Debugf(ctx, "Found registry policy file %q", policyPath)
+
+			f, err = os.Open(policyPath)
+			if err != nil {
+				return err
+			}
+
+			break classLoop
+		}
+	}
+
+	if f == nil {
+		log.Debugf(ctx, "Policy %q doesn't have any policy for class %q", name, objectClass)
+		return nil
+	}
+
+	defer decorate.LogFuncOnErrorContext(ctx, f.Close)
+
+	// Decode and apply policies in gpo order. First win
+	pols, err := registry.DecodePolicy(f)
+	if err != nil {
+		return errors.New(gotext.Get("%s: %v", f.Name(), err))
+	}
+
+	// filter keys to be overridden
+	var currentKey string
+	var overrideEnabled bool
+	for _, pol := range pols {
+		// Rewrite the certificate autoenrollment key so we can easily
+		// use it in the policy manager
+		if pol.Key == certAutoEnrollKey {
+			pol.Key = fmt.Sprintf("%scertificate/autoenroll/all", keyFilterPrefix)
+		}
+
+		if strings.HasPrefix(pol.Key, policyServersPrefix) {
+			pol.Key = fmt.Sprintf("%scertificate/%s/all", keyFilterPrefix, pol.Key)
+		}
+
+		// Only consider supported policies for this distro
+		if !strings.HasPrefix(pol.Key, keyFilterPrefix) {
+			continue
+		}
+		if pol.Err != nil {
+			return errors.New(gotext.Get("%s: %v", f.Name(), pol.Err))
+		}
+		pol.Key = strings.TrimPrefix(pol.Key, keyFilterPrefix)
+
+		// Some keys can be overridden
+		releaseID := filepath.Base(pol.Key)
+		keyType := strings.Split(pol.Key, "/")[0]
+		pol.Key = filepath.Dir(strings.TrimPrefix(pol.Key, keyType+"/"))
+
+		if releaseID == "all" {
+			currentKey = pol.Key
+			overrideEnabled = false
+			gpoWithRules.Rules[keyType] = append(gpoWithRules.Rules[keyType], pol)
+			continue
+		}
+
+		// This is not an "all" key and the key name don’t match
+		// This shouldn’t happen with our admx, but just to stay safe…
+		if currentKey != pol.Key {
+			continue
+		}
+
+		if strings.HasPrefix(releaseID, "Override"+ad.versionID) && pol.Value == "true" {
+			overrideEnabled = true
+			continue
+		}
+		// Check we have a matching override
+		if !overrideEnabled || releaseID != ad.versionID {
+			continue
+		}
+
+		// Matching enabled override
+		// Replace value with the override content
+		iLast := len(gpoWithRules.Rules[keyType]) - 1
+		p := gpoWithRules.Rules[keyType][iLast]
+		p.Value = pol.Value
+		gpoWithRules.Rules[keyType][iLast] = p
+	}
+
+	return nil
+}
+
 // GetInfo returns all information from the selected backend: static and dynamic part.
 func (ad *AD) GetInfo(ctx context.Context) (msg string) {
 	// static part
@@ -600,9 +630,9 @@ func (ad *AD) GetInfo(ctx context.Context) (msg string) {
 	var online string
 	if isOnline, err := ad.configBackend.IsOnline(); err != nil {
 		log.Warning(ctx, err)
-		online = fmt.Sprint(i18n.G("**Can't check if we have an active connection**\n"))
+		online = fmt.Sprint(gotext.Get("**Can't check if we have an active connection**\n"))
 	} else if !isOnline {
-		online = fmt.Sprint(i18n.G("**Offline mode** using cached policies\n"))
+		online = fmt.Sprint(gotext.Get("**Offline mode** using cached policies\n"))
 	}
 	domain := ad.configBackend.Domain()
 	server, err := ad.configBackend.ServerFQDN(ctx)
@@ -610,7 +640,7 @@ func (ad *AD) GetInfo(ctx context.Context) (msg string) {
 		server = "Unknown"
 	}
 
-	return fmt.Sprintf(i18n.G("%s\n%sDomain: %s\nServer FQDN: %s"), config, online, domain, server)
+	return gotext.Get("%s\n%sDomain: %s\nServer FQDN: %s", config, online, domain, server)
 }
 
 // NormalizeTargetName transforms the specified target to values adsys knows.
@@ -648,10 +678,10 @@ func (ad *AD) NormalizeTargetName(ctx context.Context, target string, objectClas
 	case 1:
 		baseUser = c[0]
 	default:
-		return "", fmt.Errorf(i18n.G(`only one \ is permitted in domain\username. Got: %s`), target)
+		return "", errors.New(gotext.Get(`only one \ is permitted in domain\username. Got: %s`, target))
 	}
 	if domainSuffix == "" && ad.configBackend.DefaultDomainSuffix() == "" {
-		return "", fmt.Errorf(i18n.G(`no domain provided for user %q and no default domain in sssd.conf`), target)
+		return "", errors.New(gotext.Get(`no domain provided for user %q and no default domain in sssd.conf`, target))
 	}
 	if domainSuffix == "" {
 		domainSuffix = ad.configBackend.DefaultDomainSuffix()
