@@ -1,4 +1,4 @@
-// Package adcommon includes utilities for packages depending on ad
+// Package adcommon includes utilities for packages depending on ad.
 package adcommon
 
 import (
@@ -8,8 +8,8 @@ import (
 	"path/filepath"
 	"strings"
 
-	"github.com/ubuntu/adsys/internal/decorate"
-	"github.com/ubuntu/adsys/internal/i18n"
+	"github.com/leonelquinteros/gotext"
+	"github.com/ubuntu/decorate"
 )
 
 // KeyPrefix is the prefix for all our policies in the GPO.
@@ -17,7 +17,7 @@ const KeyPrefix = "Software/Policies"
 
 // GetVersionID returns from root a the VERSION_ID field of os-release.
 func GetVersionID(root string) (versionID string, err error) {
-	defer decorate.OnError(&err, i18n.G("cannot get versionID"))
+	defer decorate.OnError(&err, gotext.Get("cannot get versionID"))
 
 	releaseFile := filepath.Join(root, "etc/os-release")
 
