@@ -8,6 +8,7 @@ import (
 	"errors"
 	"fmt"
 	"io"
+	"math"
 	"os"
 	"os/user"
 	"path/filepath"
@@ -15,9 +16,9 @@ import (
 	"strings"
 
 	"github.com/godbus/dbus/v5"
-	"github.com/ubuntu/adsys/internal/decorate"
+	"github.com/leonelquinteros/gotext"
 	log "github.com/ubuntu/adsys/internal/grpc/logstreamer"
-	"github.com/ubuntu/adsys/internal/i18n"
+	"github.com/ubuntu/decorate"
 	"google.golang.org/grpc/peer"
 )
 
@@ -53,7 +54,7 @@ func withRoot(root string) func(*Authorizer) {
 
 // New returns a new authorizer.
 func New(bus *dbus.Conn, options ...func(*Authorizer)) (auth *Authorizer, err error) {
-	defer decorate.OnError(&err, i18n.G("can't create new authorizer"))
+	defer decorate.OnError(&err, gotext.Get("can't create new authorizer"))
 
 	authority := bus.Object("org.freedesktop.PolicyKit1",
 		"/org/freedesktop/PolicyKit1/Authority")
@@ -71,7 +72,7 @@ func New(bus *dbus.Conn, options ...func(*Authorizer)) (auth *Authorizer, err er
 	return &a, nil
 }
 
-// Action is an polkit action
+// Action is an polkit action.
 type Action struct {
 	ID      string
 	SelfID  string
@@ -80,7 +81,7 @@ type Action struct {
 
 var (
 	// ActionAlwaysAllowed is a no-op bypassing any user or dbus checks.
-	ActionAlwaysAllowed Action = Action{ID: "always-allowed"}
+	ActionAlwaysAllowed = Action{ID: "always-allowed"}
 )
 
 type polkitCheckFlags uint32
@@ -91,7 +92,7 @@ const (
 
 type onUserKey string
 
-// OnUserKey is the authorizer context key passing optional user name
+// OnUserKey is the authorizer context key passing optional user name.
 var OnUserKey onUserKey = "UserName"
 
 type authSubject struct {
@@ -106,19 +107,19 @@ type authResult struct {
 }
 
 // IsAllowedFromContext returns nil if the user is allowed to perform an operation.
-// The pid and uid are extracted from peerCredsInfo grpc context
+// The pid and uid are extracted from peerCredsInfo grpc context.
 func (a Authorizer) IsAllowedFromContext(ctx context.Context, action Action) (err error) {
-	log.Debug(ctx, i18n.G("Check if grpc request peer is authorized"))
+	log.Debug(ctx, gotext.Get("Check if grpc request peer is authorized"))
 
-	defer decorate.OnError(&err, i18n.G("permission denied"))
+	defer decorate.OnError(&err, gotext.Get("permission denied"))
 
 	p, ok := peer.FromContext(ctx)
 	if !ok {
-		return errors.New(i18n.G("context request doesn't have grpc peer creds informations."))
+		return errors.New(gotext.Get("context request doesn't have grpc peer creds informations."))
 	}
 	pci, ok := p.AuthInfo.(peerCredsInfo)
 	if !ok {
-		return errors.New(i18n.G("context request grpc peer creeds information is not a peerCredsInfo."))
+		return errors.New(gotext.Get("context request grpc peer creeds information is not a peerCredsInfo."))
 	}
 
 	// Is it an action needing user checking?
@@ -126,16 +127,21 @@ func (a Authorizer) IsAllowedFromContext(ctx context.Context, action Action) (er
 	if action.SelfID != "" {
 		userName, ok := ctx.Value(OnUserKey).(string)
 		if !ok {
-			return errors.New(i18n.G("request to act on user action should have a user name attached"))
+			return errors.New(gotext.Get("request to act on user action should have a user name attached"))
 		}
 		user, err := a.userLookup(userName)
 		if err != nil {
-			return fmt.Errorf(i18n.G("couldn't retrieve user for %q: %v"), userName, err)
+			return errors.New(gotext.Get("couldn't retrieve user for %q: %v", userName, err))
 		}
-		uid, err := strconv.Atoi(user.Uid)
+		uid, err := strconv.ParseUint(user.Uid, 10, 0)
 		if err != nil {
-			return fmt.Errorf(i18n.G("couldn't convert %q to a valid uid for %q"), user.Uid, userName)
+			return errors.New(gotext.Get("couldn't convert %q to a valid uid for %q", user.Uid, userName))
 		}
+		if uid > math.MaxUint32 {
+			return errors.New(gotext.Get("uid value %d is too large to convert to an uint32", uid))
+		}
+
+		//nolint:gosec // we did the overflow conversion check above.
 		actionUID = uint32(uid)
 	}
 
@@ -144,13 +150,13 @@ func (a Authorizer) IsAllowedFromContext(ctx context.Context, action Action) (er
 
 // isAllowed returns nil if the user is allowed to perform an operation.
 // ActionUID is only used for ActionUserWrite which will be converted to corresponding polkit action
-// (self or others)
+// (self or others).
 func (a Authorizer) isAllowed(ctx context.Context, action Action, pid int32, uid uint32, actionUID uint32) error {
 	if uid == 0 {
-		log.Debug(ctx, i18n.G("Authorized as being administrator"))
+		log.Debug(ctx, gotext.Get("Authorized as being administrator"))
 		return nil
 	} else if action == ActionAlwaysAllowed {
-		log.Debug(ctx, i18n.G("Any user always authorized"))
+		log.Debug(ctx, gotext.Get("Any user always authorized"))
 		return nil
 	} else if action.SelfID != "" {
 		action.ID = action.OtherID
@@ -161,7 +167,7 @@ func (a Authorizer) isAllowed(ctx context.Context, action Action, pid int32, uid
 
 	f, err := os.Open(filepath.Join(a.root, fmt.Sprintf("proc/%d/stat", pid)))
 	if err != nil {
-		return fmt.Errorf(i18n.G("couldn't open stat file for process: %v"), err)
+		return errors.New(gotext.Get("couldn't open stat file for process: %v", err))
 	}
 	defer decorate.LogFuncOnErrorContext(ctx, f.Close)
 
@@ -170,10 +176,16 @@ func (a Authorizer) isAllowed(ctx context.Context, action Action, pid int32, uid
 		return err
 	}
 
+	// polkit requests an uint32 on dbus
+	var upid uint32
+	if pid > 0 {
+		upid = uint32(pid)
+	}
+
 	subject := authSubject{
 		Kind: "unix-process",
 		Details: map[string]dbus.Variant{
-			"pid":        dbus.MakeVariant(uint32(pid)), // polkit requests an uint32 on dbus
+			"pid":        dbus.MakeVariant(upid),
 			"start-time": dbus.MakeVariant(startTime),
 			"uid":        dbus.MakeVariant(uid),
 		},
@@ -185,13 +197,13 @@ func (a Authorizer) isAllowed(ctx context.Context, action Action, pid int32, uid
 		"org.freedesktop.PolicyKit1.Authority.CheckAuthorization", dbus.FlagAllowInteractiveAuthorization,
 		subject, action.ID, details, checkAllowInteraction, "").Store(&result)
 	if err != nil {
-		return fmt.Errorf(i18n.G("call to polkit failed: %v"), err)
+		return errors.New(gotext.Get("call to polkit failed: %v", err))
 	}
 
-	log.Debugf(ctx, i18n.G("Polkit call result, authorized: %t"), result.IsAuthorized)
+	log.Debug(ctx, gotext.Get("Polkit call result, authorized: %t", result.IsAuthorized))
 
 	if !result.IsAuthorized {
-		return errors.New(i18n.G("polkit denied access"))
+		return errors.New(gotext.Get("polkit denied access"))
 	}
 	return nil
 }
@@ -199,9 +211,10 @@ func (a Authorizer) isAllowed(ctx context.Context, action Action, pid int32, uid
 // getStartTimeFromReader determines the start time from a process stat file content
 //
 // The implementation is intended to be compatible with polkit:
-//    https://cgit.freedesktop.org/polkit/tree/src/polkit/polkitunixprocess.c
+//
+//	https://cgit.freedesktop.org/polkit/tree/src/polkit/polkitunixprocess.c
 func getStartTimeFromReader(r io.Reader) (t uint64, err error) {
-	defer decorate.OnError(&err, i18n.G("can't determine start time of client process"))
+	defer decorate.OnError(&err, gotext.Get("can't determine start time of client process"))
 
 	data, err := io.ReadAll(r)
 	if err != nil {
@@ -219,19 +232,19 @@ func getStartTimeFromReader(r io.Reader) (t uint64, err error) {
 	// starttime field.
 	idx := strings.IndexByte(contents, ')')
 	if idx < 0 {
-		return 0, errors.New(i18n.G("parsing error: missing )"))
+		return 0, errors.New(gotext.Get("parsing error: missing )"))
 	}
 	idx += 2 // skip ") "
 	if idx > len(contents) {
-		return 0, errors.New(i18n.G("parsing error: ) at the end"))
+		return 0, errors.New(gotext.Get("parsing error: ) at the end"))
 	}
 	tokens := strings.Split(contents[idx:], " ")
 	if len(tokens) < 20 {
-		return 0, errors.New(i18n.G("parsing error: less fields than required"))
+		return 0, errors.New(gotext.Get("parsing error: less fields than required"))
 	}
 	v, err := strconv.ParseUint(tokens[19], 10, 64)
 	if err != nil {
-		return 0, fmt.Errorf(i18n.G("parsing error: %v"), err)
+		return 0, errors.New(gotext.Get("parsing error: %v", err))
 	}
 	return v, nil
 }
