@@ -40,9 +40,9 @@ import (
 	"sync"
 
 	"github.com/godbus/dbus/v5"
+	"github.com/leonelquinteros/gotext"
 	"github.com/ubuntu/adsys/internal/consts"
 	log "github.com/ubuntu/adsys/internal/grpc/logstreamer"
-	"github.com/ubuntu/adsys/internal/i18n"
 	"github.com/ubuntu/adsys/internal/policies/entry"
 	"github.com/ubuntu/adsys/internal/smbsafe"
 	"github.com/ubuntu/decorate"
@@ -50,7 +50,11 @@ import (
 
 // Manager prevents running multiple dconf update process in parallel while parsing policy in ApplyPolicy.
 type Manager struct {
+	// dconfMu prevents applying dconf policies for users and machine in parallel.
+	// Applying the policy for the machine can only be done if we are not applying it for any user.
 	dconfMu sync.RWMutex
+	// dconfUpdateMu prevents running multiple dconf update processes in parallel.
+	dconfUpdateMu sync.Mutex
 
 	dconfDir string
 }
@@ -62,14 +66,25 @@ func NewWithDconfDir(dir string) *Manager {
 
 // ApplyPolicy generates a dconf computer or user policy based on a list of entries.
 func (m *Manager) ApplyPolicy(ctx context.Context, objectName string, isComputer bool, entries []entry.Entry) (err error) {
-	defer decorate.OnError(&err, i18n.G("can't apply dconf policy to %s"), objectName)
+	defer decorate.OnError(&err, gotext.Get("can't apply dconf policy to %s", objectName))
 
 	dconfDir := m.dconfDir
 	if dconfDir == "" {
 		dconfDir = consts.DefaultDconfDir
 	}
 
-	m.dconfMu.RLock()
+	// Since the user dconf configuration is reliant on the machine dconf configuration, we can't
+	// apply them in parallel. The strategy works as follows:
+	// 	- Any number of users can have the policy applied in parallel;
+	//	- Machine policy can't be applied if there are any user policies being applied;
+	// dconfMu is used to prevent that.
+	if isComputer {
+		m.dconfMu.Lock()
+		defer m.dconfMu.Unlock()
+	} else {
+		m.dconfMu.RLock()
+		defer m.dconfMu.RUnlock()
+	}
 
 	log.Debugf(ctx, "Applying dconf policy to %s", objectName)
 
@@ -82,21 +97,17 @@ func (m *Manager) ApplyPolicy(ctx context.Context, objectName string, isComputer
 
 	if !isComputer {
 		if _, err := os.Stat(filepath.Join(dbsPath, "machine.d", "locks", "adsys")); err != nil {
-			m.dconfMu.RUnlock()
-			return fmt.Errorf(i18n.G("machine dconf database is required before generating a policy for an user. This one returns: %v"), err)
+			return errors.New(gotext.Get("machine dconf database is required before generating a policy for an user. This one returns: %v", err))
 		}
 	}
 
 	// Create profiles for users only
 	if !isComputer {
-		// Profile must be readable by everyone
-		// #nosec G301
+		//nolint:gosec // G301 - Profile must be readable by everyone
 		if err := os.MkdirAll(profilesPath, 0755); err != nil {
-			m.dconfMu.RUnlock()
 			return err
 		}
 		if err := writeProfile(ctx, objectName, profilesPath); err != nil {
-			m.dconfMu.RUnlock()
 			return err
 		}
 	}
@@ -114,7 +125,7 @@ func (m *Manager) ApplyPolicy(ctx context.Context, objectName string, isComputer
 			// normalize common user error cases and check gsettings schema signature match.
 			e.Value = normalizeValue(e.Meta, e.Value)
 			if err := checkSignature(e.Meta, e.Value); err != nil {
-				errMsgs = append(errMsgs, fmt.Sprintf(i18n.G("- error on %s: %v"), e.Key, err))
+				errMsgs = append(errMsgs, gotext.Get("- error on %s: %v", e.Key, err))
 				continue
 			}
 
@@ -126,7 +137,6 @@ func (m *Manager) ApplyPolicy(ctx context.Context, objectName string, isComputer
 
 	// Stop on any error
 	if errMsgs != nil {
-		m.dconfMu.RUnlock()
 		return errors.New(strings.Join(errMsgs, "\n"))
 	}
 
@@ -146,17 +156,14 @@ func (m *Manager) ApplyPolicy(ctx context.Context, objectName string, isComputer
 	var needsRefresh bool
 
 	// Commit on disk
-	// Locks must be readable by everyone
-	// #nosec G301
+	//nolint:gosec // G301 - Locks must be readable by everyone
 	if err := os.MkdirAll(filepath.Join(dbPath, "locks"), 0755); err != nil {
-		m.dconfMu.RUnlock()
 		return err
 	}
 
 	defaultPath := filepath.Join(dbPath, "adsys")
 	changed, err := writeIfChanged(defaultPath, strings.Join(data, "\n")+"\n")
 	if err != nil {
-		m.dconfMu.RUnlock()
 		return err
 	}
 	needsRefresh = needsRefresh || changed
@@ -164,13 +171,10 @@ func (m *Manager) ApplyPolicy(ctx context.Context, objectName string, isComputer
 	locksPath := filepath.Join(dbPath, "locks", "adsys")
 	changed, err = writeIfChanged(locksPath, strings.Join(locks, "\n")+"\n")
 	if err != nil {
-		m.dconfMu.RUnlock()
 		return err
 	}
 	needsRefresh = needsRefresh || changed
 
-	m.dconfMu.RUnlock()
-
 	// update if any profile changed, or if any compiled db is missing
 	needsRefresh = needsRefresh || dconfNeedsUpdate(filepath.Join(dbsPath, "machine"))
 	if !isComputer {
@@ -183,13 +187,13 @@ func (m *Manager) ApplyPolicy(ctx context.Context, objectName string, isComputer
 	// request an update now that we released the read lock
 	// we will call update multiple times.
 	smbsafe.WaitExec()
-	m.dconfMu.Lock()
+	m.dconfUpdateMu.Lock()
 	// #nosec G204 - we control the input
 	out, errExec := exec.Command("dconf", "update", filepath.Join(dconfDir, "db")).CombinedOutput()
-	m.dconfMu.Unlock()
+	m.dconfUpdateMu.Unlock()
 	smbsafe.DoneExec()
 	if errExec != nil {
-		err = fmt.Errorf(i18n.G("dconf update failed: %v"), out)
+		err = errors.New(gotext.Get("dconf update failed: %v", out))
 	}
 
 	return nil
@@ -197,13 +201,13 @@ func (m *Manager) ApplyPolicy(ctx context.Context, objectName string, isComputer
 
 // writeIfChanged will only write to path if content is different from current content.
 func writeIfChanged(path string, content string) (done bool, err error) {
-	defer decorate.OnError(&err, i18n.G("can't save %s"), path)
+	defer decorate.OnError(&err, gotext.Get("can't save %s", path))
 
 	if oldContent, err := os.ReadFile(path); err == nil && string(oldContent) == content {
 		return false, nil
 	}
 
-	// #nosec G306. This asset needs to be world-readable.
+	//nolint:gosec // G306 - This asset needs to be world-readable.
 	if err := os.WriteFile(path+".new", []byte(content), 0644); err != nil {
 		return false, err
 	}
@@ -215,10 +219,10 @@ func writeIfChanged(path string, content string) (done bool, err error) {
 }
 
 // writeProfile creates or updates a dconf profile file.
-// The adsys systemd-db should always be the first systemd-db in the file to enforce their values
-// (upper systemd-db in the profile wins).
+// The adsys system-db should always be the first system-db in the file to enforce their values
+// (upper system-db in the profile wins).
 func writeProfile(ctx context.Context, user, profilesPath string) (err error) {
-	defer decorate.OnError(&err, i18n.G("can't update user profile %s"), profilesPath)
+	defer decorate.OnError(&err, gotext.Get("can't update user profile %s", profilesPath))
 
 	profilePath := filepath.Join(profilesPath, user)
 	log.Debugf(ctx, "Update user profile %s", profilePath)
@@ -255,7 +259,7 @@ func writeProfile(ctx context.Context, user, profilesPath string) (err error) {
 	}
 
 	// Otherwise, update the file.
-	// #nosec G306. This asset needs to be world-readable.
+	//nolint:gosec // G306 - This asset needs to be world-readable.
 	if err := os.WriteFile(profilePath+".adsys.new", newContent, 0644); err != nil {
 		return err
 	}
@@ -298,9 +302,10 @@ func normalizeValue(keyType, value string) string {
 // We will escape each non leading character in s.
 func quoteValue(s string) string {
 	// quote automatically single quote
-	if s == "'" {
+	switch s {
+	case "'":
 		s = `'''`
-	} else if s == `\'` {
+	case `\'`:
 		s = `'\''`
 	}
 
@@ -409,19 +414,19 @@ func splitOnNonEscaped(v, sep string) []string {
 
 // checkSignature returns an error if the value doesn't match the expected variant signature.
 func checkSignature(meta, value string) (err error) {
-	defer decorate.OnError(&err, i18n.G("error while checking signature"))
+	defer decorate.OnError(&err, gotext.Get("error while checking signature"))
 
 	if meta == "" {
-		return fmt.Errorf(i18n.G("empty signature for %v"), meta)
+		return errors.New(gotext.Get("empty signature for %v", meta))
 	}
 
 	sig, err := dbus.ParseSignature(meta)
 	if err != nil {
-		return fmt.Errorf(i18n.G("%s is not a valid gsettings signature: %v"), meta, err)
+		return errors.New(gotext.Get("%s is not a valid gsettings signature: %v", meta, err))
 	}
 	_, err = dbus.ParseVariant(value, sig)
 	if err != nil {
-		return fmt.Errorf(i18n.G("can't parse %q as %q: %v"), value, meta, err)
+		return errors.New(gotext.Get("can't parse %q as %q: %v", value, meta, err))
 	}
 
 	return nil
