@@ -1,3 +1,5 @@
+// Package entry contains the Entry type, which is the bridge between AD and adsys minimal item, containing
+// every information to apply.
 package entry
 
 // Entry represents a key/value based policy (dconf, apparmor, ...) entry.
@@ -11,6 +13,9 @@ type Entry struct {
 	// Strategy are overlay rules for the same keys between multiple GPOs.
 	// Default (empty or unknown value) means "override".
 	Strategy string `yaml:",omitempty"`
+	// Err is set if there was an error parsing the entry. It is ignored if the
+	// underlying key is not supported by adsys.
+	Err error `yaml:"-"`
 }
 
 const (
