@@ -65,8 +65,6 @@ func TestApplyPolicies(t *testing.T) {
 		"Error when applying certificate policy": {policiesDir: "certificate_failing", wantErr: true},
 	}
 	for name, tc := range tests {
-		tc := tc
-		name := name
 		t.Run(name, func(t *testing.T) {
 			// We change the dbus returned values to simulate a subscription
 			//t.Parallel()
@@ -80,6 +78,7 @@ func TestApplyPolicies(t *testing.T) {
 			runDir := filepath.Join(fakeRootDir, "run", "adsys")
 			dconfDir := filepath.Join(fakeRootDir, "etc", "dconf")
 			policyKitDir := filepath.Join(fakeRootDir, "etc", "polkit-1")
+			policyKitReservedDir := filepath.Join(fakeRootDir, "usr", "share", "polkit-1")
 			sudoersDir := filepath.Join(fakeRootDir, "etc", "sudoers.d")
 			apparmorDir := filepath.Join(fakeRootDir, "etc", "apparmor.d", "adsys")
 			systemUnitDir := filepath.Join(fakeRootDir, "etc", "systemd", "system")
@@ -92,10 +91,7 @@ func TestApplyPolicies(t *testing.T) {
 			err = os.WriteFile(loadedPoliciesFile, []byte("someprofile (enforce)\n"), 0600)
 			require.NoError(t, err, "Setup: can not create loadedPoliciesFile")
 
-			status := true
-			if tc.isNotSubscribed {
-				status = false
-			}
+			status := !tc.isNotSubscribed
 			require.NoError(t, subscriptionDbus.SetProperty(consts.SubscriptionDbusInterface+".Attached", status), "Setup: can not set subscription status to %q", status)
 			defer func() {
 				require.NoError(t, subscriptionDbus.SetProperty(consts.SubscriptionDbusInterface+".Attached", false), "Teardown: can not restore subscription status")
@@ -110,6 +106,7 @@ func TestApplyPolicies(t *testing.T) {
 				policies.WithShareDir(shareDir),
 				policies.WithDconfDir(dconfDir),
 				policies.WithPolicyKitDir(policyKitDir),
+				policies.WithPolicyKitSystemDir(policyKitReservedDir),
 				policies.WithSudoersDir(sudoersDir),
 				policies.WithApparmorDir(apparmorDir),
 				policies.WithApparmorFsDir(filepath.Dir(loadedPoliciesFile)),
@@ -179,7 +176,7 @@ func TestApplyPolicies(t *testing.T) {
 				require.NoError(t, err, "ApplyPolicy should return no error but got one")
 			}
 
-			testutils.CompareTreesWithFiltering(t, fakeRootDir, testutils.GoldenPath(t), testutils.Update())
+			testutils.CompareTreesWithFiltering(t, fakeRootDir, testutils.GoldenPath(t), testutils.UpdateEnabled())
 		})
 	}
 }
@@ -285,8 +282,6 @@ func TestDumpPolicies(t *testing.T) {
 	}
 
 	for name, tc := range tests {
-		tc := tc
-		name := name
 		t.Run(name, func(t *testing.T) {
 			t.Parallel()
 
@@ -352,8 +347,6 @@ func TestLastUpdateFor(t *testing.T) {
 	}
 
 	for name, tc := range tests {
-		tc := tc
-		name := name
 		t.Run(name, func(t *testing.T) {
 			t.Parallel()
 
@@ -408,8 +401,6 @@ func TestGetSubscriptionState(t *testing.T) {
 	}
 
 	for name, tc := range tests {
-		tc := tc
-		name := name
 		t.Run(name, func(t *testing.T) {
 			// We change the dbus returned values to simulate a subscription
 			//t.Parallel()
