@@ -3,7 +3,7 @@
 package tools
 
 import (
-	_ "github.com/golangci/golangci-lint/cmd/golangci-lint"
+	_ "github.com/golangci/golangci-lint/v2/cmd/golangci-lint"
 	_ "google.golang.org/grpc/cmd/protoc-gen-go-grpc"
 	_ "github.com/golang/protobuf/protoc-gen-go"
 )
